@@ -2044,7 +2044,6 @@ posix_fs_health_check(xlator_t *this)
     if (ret != 0) {
         op_errno = errno;
         op = "aio_write_error";
-        ret = -1;
         goto out;
     }
 
@@ -2083,7 +2082,6 @@ posix_fs_health_check(xlator_t *this)
     if (ret != 0) {
         op_errno = errno;
         op = "aio_read_error";
-        ret = -1;
         goto out;
     }
 
@@ -2108,7 +2106,8 @@ out:
     }
     if (ret && file_path[0]) {
         gf_msg(this->name, GF_LOG_WARNING, errno, P_MSG_HEALTHCHECK_FAILED,
-               "%s() on %s returned", op, file_path);
+               "%s() on %s returned ret is %d error is %s", op, file_path, ret,
+               ret != -1 ? strerror(ret) : strerror(op_errno));
         gf_event(EVENT_POSIX_HEALTH_CHECK_FAILED,
                  "op=%s;path=%s;error=%s;brick=%s:%s timeout is %d", op,
                  file_path, strerror(op_errno), priv->hostname, priv->base_path,
@@ -2828,7 +2827,8 @@ __posix_inode_ctx_get(inode_t *inode, xlator_t *this)
     pthread_mutex_init(&ctx_p->write_atomic_lock, NULL);
     pthread_mutex_init(&ctx_p->pgfid_lock, NULL);
 
-    ret = __inode_ctx_set(inode, this, (uint64_t *)&ctx_p);
+    ctx_uint = (uint64_t)(uintptr_t)ctx_p;
+    ret = __inode_ctx_set(inode, this, &ctx_uint);
     if (ret < 0) {
         pthread_mutex_destroy(&ctx_p->xattrop_lock);
         pthread_mutex_destroy(&ctx_p->write_atomic_lock);
